==> mongodb-driver-core-4.2.0-sources.jar: com/mongodb/management/JMXMBeanServer.java <==
/*
 * Copyright 2008-present MongoDB, Inc.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package com.mongodb.management;

import com.mongodb.diagnostics.logging.Logger;
import com.mongodb.diagnostics.logging.Loggers;

import javax.management.ObjectName;
import java.lang.management.ManagementFactory;

class JMXMBeanServer implements MBeanServer {
    private static final Logger LOGGER = Loggers.getLogger("management");

    @Override
    public void registerMBean(final Object mBean, final String mBeanName) {
        try {
            server.registerMBean(mBean, new ObjectName(mBeanName));
        } catch (Exception e) {
            LOGGER.warn("Unable to register MBean " + mBeanName, e);
        }
    }

    @Override
    public void unregisterMBean(final String mBeanName) {
        try {
            ObjectName objectName = new ObjectName(mBeanName);
            if (server.isRegistered(objectName)) {
                server.unregisterMBean(objectName);
            }
        } catch (Exception e) {
            LOGGER.warn("Unable to unregister MBean " + mBeanName, e);
        }
    }

    private final javax.management.MBeanServer server = ManagementFactory.getPlatformMBeanServer();
}

==> mongodb-driver-core-4.11.1-sources.jar: com/mongodb/management/JMXMBeanServer.java <==
/*
 * Copyright 2008-present MongoDB, Inc.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *   http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package com.mongodb.management;

import com.mongodb.internal.diagnostics.logging.Logger;
import com.mongodb.internal.diagnostics.logging.Loggers;

import javax.management.ObjectName;
import java.lang.management.ManagementFactory;

class JMXMBeanServer implements MBeanServer {
    private static final Logger LOGGER = Loggers.getLogger("management");

    @Override
    public void registerMBean(final Object mBean, final String mBeanName) {
        try {
            server.registerMBean(mBean, new ObjectName(mBeanName));
        } catch (Exception e) {
            LOGGER.warn("Unable to register MBean " + mBeanName, e);
        }
    }

    @Override
    public void unregisterMBean(final String mBeanName) {
        try {
            ObjectName objectName = new ObjectName(mBeanName);
            if (server.isRegistered(objectName)) {
                server.unregisterMBean(objectName);
            }
        } catch (Exception e) {
            LOGGER.warn("Unable to unregister MBean " + mBeanName, e);
        }
    }

    private final javax.management.MBeanServer server = ManagementFactory.getPlatformMBeanServer();
}
